% File: Figure_1_3.m
% Euler method versus symplectic Euler's method for the pendulum
% It requires the following functions:
%eulerE.m
%eulerI.m
%eulerTV.m
%eulerVT.m
%fPendulum.m
%fPendulumT
%fPendulumV
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
t0=0; tf=6*pi; 
for i=1:6
% Initial conditions
  x0 = [i/2 ; 0];
  [t,x] = ode45('fPendulum',[t0,tf],x0);
  figure(1)
   subplot(1,2,1)
    hold on
    plot(x(:,1),x(:,2),'g:','LineWidth',1,'Color',[0 0 0]+0.85)
    box
   subplot(1,2,2)
    hold on
    plot(x(:,1),x(:,2),'g:','LineWidth',1,'Color',[0 0 0]+0.85)
    box
end
% Initial and final time, and time step
t0=0;  tf1=pi/2;  tf=pi;   N = 6;  h = (tf-t0)/N;
xx0=[]; xf1=[]; xf2=[]; xf1i=[]; xf2i=[]; xTVf1=[]; 
xTVf2=[]; xVTf1=[]; xVTf2=[]; xef1=[]; xef2=[]; idots=50;
idots1=20;
idots2=20;
idots3=60;
idots=idots1+idots2+idots3;
a1=3/2+cos(pi*5/6)/2;  b1=sin(pi*5/6)/2;
a2=3/2;                 b2=0;
a3=3/2+cos(-pi*5/6)/2;   b3=sin(-pi*5/6)/2;
for i=0:idots
    
 if i <=idots1
     x00(i+1)=a1+(i/idots1)*(a2-a1)
     y00(i+1)=b1+(i/idots1)*(b2-b1);
 elseif  i <(idots1+idots2)
     i
     x00(i+1)=a2+((i-idots1)/idots2)*(a3-a2);
     y00(i+1)=b2+((i-idots1)/idots2)*(b3-b2);
 else
     thet=-pi*5/6+2*pi*(5/6)*(i-idots1-idots2)/(idots3)
     x00(i+1)=3/2+cos(thet)/2
     y00(i+1)=sin(thet)/2;
 end     
     
end

for i=0:idots
%  x0 = [3/2+cos(2*pi*i/idots)/2 ; sin(2*pi*i/idots)/2];
%  q0=x0(1);  p0=x0(2);
%  xx0=[xx0; x0'];
  x0 = [x00(i+1) ; y00(i+1)];
  q0=x0(1);  p0=x0(2);
  xx0=[xx0; x0'];
   
  [t1,xe1] = ode45('fPendulum',[t0,tf1],x0);
  xef1=[xef1; xe1(end,1),xe1(end,2)];
  [t2,xe2] = ode45('fPendulum',[t0,tf],x0);
  xef2=[xef2; xe2(end,1),xe2(end,2)];
  
  [t x1]=eulerE(@fPendulum,t0,tf,x0,N);
  [t x1i]=eulerI(@fPendulum,t0,tf,x0,N);
  [t q1 p1]=eulerTV(@fPendulumT,@fPendulumV,t0,tf,q0,p0,N);
  [t q2 p2]=eulerVT(@fPendulumT,@fPendulumV,t0,tf,q0,p0,N);

  xf1=[xf1; x1(4,:)];     xf2=[xf2; x1(end,:)];
  xf1i=[xf1i; x1i(4,:)];     xf2i=[xf2i; x1i(end,:)];
  xTVf1=[xTVf1; q1(4,:) p1(4,:)];  xTVf2=[xTVf2; q1(end,:) p1(end,:)];
  xVTf1=[xVTf1; q2(4,:) p2(4,:)];  xVTf2=[xVTf2; q2(end,:) p2(end,:)];
end

figure(1)
subplot(1,2,1)
hold on
plot(xf1(:,1),xf1(:,2),'k-','LineWidth',1.5)
fill(xf1(:,1),xf1(:,2),[0 0 0]+0.8)
plot(xf2(:,1),xf2(:,2),'k-','LineWidth',1.5)
fill(xf2(:,1),xf2(:,2),[0 0 0]+0.8)
plot(xf1i(:,1),xf1i(:,2),'k-','LineWidth',1.5)
fill(xf1i(:,1),xf1i(:,2),[0 0 0]+0.5)
plot(xf2i(:,1),xf2i(:,2),'k-','LineWidth',1.5)
fill(xf2i(:,1),xf2i(:,2),[0 0 0]+0.5)

plot(xx0(:,1),xx0(:,2),'k-','LineWidth',1.5)
plot(xef1(:,1),xef1(:,2),'k-','LineWidth',1.5)
plot(xef2(:,1),xef2(:,2),'k-','LineWidth',1.5)
xlabel('{\fontsize{14} q }')   
ylabel('{\fontsize{14} p}','Rotation',0)   
axis equal
axis([-3 3 -3 3 ])
%axis([-3.5 3.5 -2.5 2.5])
box

subplot(1,2,2)
hold on
plot(xTVf1(:,1),xTVf1(:,2),'k-','LineWidth',1.5)
fill(xTVf1(:,1),xTVf1(:,2),[0 0 0]+0.8)
plot(xTVf2(:,1),xTVf2(:,2),'k-','LineWidth',1.5)
fill(xTVf2(:,1),xTVf2(:,2),[0 0 0]+0.8)
plot(xVTf1(:,1),xVTf1(:,2),'k-','LineWidth',1.5)
fill(xVTf1(:,1),xVTf1(:,2),[0 0 0]+0.5)
plot(xVTf2(:,1),xVTf2(:,2),'k-','LineWidth',1.5)
fill(xVTf2(:,1),xVTf2(:,2),[0 0 0]+0.5)

plot(xx0(:,1),xx0(:,2),'k-','LineWidth',1.5)
plot(xef1(:,1),xef1(:,2),'k-','LineWidth',1.5)
plot(xef2(:,1),xef2(:,2),'k-','LineWidth',1.5)
xlabel('{\fontsize{14} q }')   
ylabel('{\fontsize{14} p}','Rotation',0)   
axis equal
axis([-3 3 -3 3 ])
%axis([-3.5 3.5 -2.5 2.5])
box

